



if not exist %LIBRARY_INC%\\json\\json.h exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %LIBRARY_BIN%\\jsoncpp.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %LIBRARY_LIB%\\jsoncpp.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
if not exist %LIBRARY_LIB%\\jsoncpp_static.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit 1
exit 0
